# == Class: snmpd
#
# Puppet module to install, deploy and configure snmpd.
#
class snmpd (
  $package            = true,
  $service            = true,
  $enable             = true,
  $systemd            = $snmpd::params::systemd,
  $snmpd_package_name = $snmpd::params::snmpd_package_name,
  $snmpd_package_deps = $snmpd::params::snmpd_package_deps,
  $snmpd_service_name = $snmpd::params::snmpd_service_name,
  $snmpd_user_name    = $snmpd::params::snmpd_user_name,
  $snmpd_group_name   = $snmpd::params::snmpd_group_name,
  $snmpd_sysconfig    = $snmpd::params::snmpd_sysconfig,
  $snmpd_systemd      = $snmpd::params::snmpd_systemd,
  $snmpd_options      = $snmpd::params::snmpd_options,
  $snmpd_config       = $snmpd::params::snmpd_config,
  # daemon settings
  $snmpdrun           = $snmpd::params::snmpdrun,
  $trapdrun           = $snmpd::params::trapdrun,
  $secname            = $snmpd::params::secname,
  $allowed_hosts      = $snmpd::params::allowed_hosts,
  $community          = $snmpd::params::community,
  $syslocation        = $snmpd::params::syslocation,
  $syscontact         = $snmpd::params::syscontact,
  $sysservices        = $snmpd::params::sysservices,
  $include            = $snmpd::params::include,
  $extend             = []
) inherits snmpd::params {
  case $package {
    true    : { $ensure_package = 'present' }
    false   : { $ensure_package = 'purged' }
    latest  : { $ensure_package = 'latest' }
    default : { fail('package must be true, false or lastest') }
  }

  case $service {
    true    : { $ensure_service = 'running' }
    false   : { $ensure_service = 'stopped' }
    default : { fail('service must be true or false') }
  }

  package { $snmpd_package_deps:
    ensure => $ensure_package,
  }

  package { $snmpd_package_name:
    ensure  => $ensure_package,
    require => Package[$snmpd_package_deps]
  }

  # systemd
  if ($::lsbdistcodename  == 'stretch') or
    ($::lsbdistcodename  == 'buster') {
    file { $systemd:
      ensure  => 'directory',
      mode    => '0755',
      require => Package[$snmpd_package_name],
    }

    file { $snmpd_systemd:
      ensure  => $ensure_package,
      backup  => true,
      content => template("snmpd/systemd.${::operatingsystem}.erb"),
      owner   => 'root',
      group   => 'root',
      mode    => '0644',
      require => File[$systemd],
      notify  => Service[$snmpd_service_name],
    }

    service { $snmpd_service_name:
      ensure   => $ensure_service,
      enable   => $enable,
      provider => 'systemd',
      require  => [ Package[$snmpd_package_name],
                    File[$systemd],
                    File[$snmpd_systemd] ],
    }
  }
  # sysvinit
  else {
    file { $snmpd_sysconfig:
      ensure  => $ensure_package,
      backup  => true,
      content => template("snmpd/sysconfig.${::operatingsystem}.erb"),
      owner   => 'root',
      group   => 'root',
      mode    => '0644',
      require => Package[$snmpd_package_name],
      notify  => Service[$snmpd_service_name],
    }

    service { $snmpd_service_name:
      ensure     => $ensure_service,
      enable     => $enable,
      hasrestart => true,
      hasstatus  => true,
      require    => Package[$snmpd_package_name],
    }
  }

  file { $snmpd_config:
    ensure  => $ensure_package,
    backup  => true,
    content => template('snmpd/snmpd.conf.erb'),
    owner   => 'root',
    group   => 'root',
    mode    => '0644',
    require => Package[$snmpd_package_name],
    notify  => Service[$snmpd_service_name],
  }

  file { '/usr/local/bin/vp-distro':
    ensure  => $ensure_package,
    backup  => true,
    source  => 'puppet:///modules/snmpd/vp-distro',
    owner   => 'root',
    group   => 'root',
    mode    => '0755',
    require => Package[$snmpd_package_name],
    notify  => Service[$snmpd_service_name],
  }

  file { '/usr/local/bin/vp-hardware':
    ensure  => $ensure_package,
    backup  => true,
    source  => 'puppet:///modules/snmpd/vp-hardware',
    owner   => 'root',
    group   => 'root',
    mode    => '0755',
    require => Package[$snmpd_package_name],
    notify  => Service[$snmpd_service_name],
  }

  file { '/usr/local/bin/vp-manufacturer':
    ensure  => $ensure_package,
    backup  => true,
    source  => 'puppet:///modules/snmpd/vp-manufacturer',
    owner   => 'root',
    group   => 'root',
    mode    => '0755',
    require => Package[$snmpd_package_name],
    notify  => Service[$snmpd_service_name],
  }

  file { '/usr/local/bin/vp-ntp-client':
    ensure  => $ensure_package,
    backup  => true,
    source  => 'puppet:///modules/snmpd/vp-ntp-client',
    owner   => 'root',
    group   => 'root',
    mode    => '0755',
    require => Package[$snmpd_package_name],
    notify  => Service[$snmpd_service_name],
  }

  file { '/usr/local/bin/vp-osupdate':
    ensure  => $ensure_package,
    backup  => true,
    source  => 'puppet:///modules/snmpd/vp-osupdate',
    owner   => 'root',
    group   => 'root',
    mode    => '0755',
    require => Package[$snmpd_package_name],
    notify  => Service[$snmpd_service_name],
  }

  file { '/usr/local/bin/vp-serial':
    ensure  => $ensure_package,
    backup  => true,
    source  => 'puppet:///modules/snmpd/vp-serial',
    owner   => 'root',
    group   => 'root',
    mode    => '0755',
    require => Package[$snmpd_package_name],
    notify  => Service[$snmpd_service_name],
  }

  file { $include:
    ensure  => $ensure_package,
    backup  => true,
    content => template('snmpd/snmpd_local.conf.erb'),
    owner   => 'root',
    group   => 'root',
    mode    => '0644',
    require => Package[$snmpd_package_name],
    notify  => Service[$snmpd_service_name]
  }
}
# EOF
